@@ -9,6 +9,8 @@ extern int Quit;
 #define BLINK_OFF 0x11
 #define BACKLIGHT_OFF 0x20
 #define BACKLIGHT_ON 0x21
+#define HOLD_SCREEN 0x30
+#define CONTINUE 0x31
 
 
 #endif
