@@ -3,10 +3,13 @@
 
 
 //TODO: Net stats screen...
-//TODO: Disk stats
 //TODO: "Who"
 //TODO: biff / mail checking
 
+// Character to use for padding title bars, etc...
+extern int PAD;
+// Character for the "..." symbol.
+extern int ELLIPSIS;
 
 int mode_init();
 void mode_close();
@@ -16,7 +19,10 @@ int cpu_graph_screen(int rep);
 int clock_screen(int rep);
 int mem_screen(int rep);
 int uptime_screen(int rep);
+int time_screen(int rep);
+int disk_screen(int rep);
 int xload_screen(int rep);
+int battery_screen(int rep);
 int credit_screen(int rep);
 int dumbass_screen(int rep);
 int goodbye_screen(int rep);
